==> apache-plc4x-0.10.0-source-release.zip: apache-plc4x-0.10.0/plc4j/drivers/profinet/src/test/java/org/apache/plc4x/java/profinet/ProfinetParserSerializerTestSuiteGenerator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.plc4x.java.profinet;

import org.apache.plc4x.java.profinet.readwrite.Ethernet_Frame;
import org.apache.plc4x.test.generator.ParserSerializerTestsuiteGenerator;

import java.nio.file.Path;

public class ProfinetParserSerializerTestSuiteGenerator {

    public static void main(String... args) {
        String pcapFile = Path.of("protocols/profinet/src/test/resources/pcap/working-profinet-recording-plc4x.pcapng").toAbsolutePath().toString();
        String xmlTestSuiteFile = Path.of("protocols/profinet/src/test/resources/protocols/profinet/ParserSerializerTestsuite.xml").toAbsolutePath().toString();
        ParserSerializerTestsuiteGenerator.main("-tProfinet", "-pprofinet", Ethernet_Frame.class.getName(), pcapFile, xmlTestSuiteFile);
    }
}

==> apache-plc4x-0.13.1-source-release.zip: apache-plc4x-0.13.1/plc4j/drivers/profinet/src/test/java/org/apache/plc4x/java/profinet/ProfinetParserSerializerTestSuiteGenerator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.plc4x.java.profinet;

import org.apache.plc4x.java.profinet.readwrite.Ethernet_Frame;
import org.apache.plc4x.test.generator.ParserSerializerTestsuiteGenerator;

import java.nio.file.Path;

public class ProfinetParserSerializerTestSuiteGenerator {

    public static void main(String... args) {
        String pcapFile = Path.of("protocols/profinet/src/test/resources/pcap/working-profinet-recording-plc4x.pcapng").toAbsolutePath().toString();
        String xmlTestSuiteFile = Path.of("protocols/profinet/src/test/resources/protocols/profinet/ParserSerializerTestsuite.xml").toAbsolutePath().toString();
        ParserSerializerTestsuiteGenerator.main("--debug", "-tProfinet", "-pprofinet", Ethernet_Frame.class.getName(), pcapFile, xmlTestSuiteFile);
    }
}
